def initKernel():
    __dark = {{THEME_IS_DARK}}
    try:
        import seaborn as sns
        sns.set_style('darkgrid' if __dark else 'whitegrid')
    except:
        pass

    try:
        from bokeh.io import curdoc
        curdoc().theme = 'dark_minimal' if __dark else 'light_minimal'
    except:
        pass

    try:
        from matplotlib import pyplot as plt
        plt.style.use('dark_background' if __dark else 'default')
    except:
        pass

#    try:
#        import matplotlib
#        %matplotlib inline
#    except:
#        pass

    try:
        import plotly.io as pio
        pio.templates.default = "plotly_dark" if __dark else "plotly"
    except:
        pass
try:
    initKernel()
except:
    pass
del initKernel
#sometimes it does not return reply and we want to force it with return smth
12